<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:optim="http://www.ibm.com/optim/audit/v11.3.0.0"
	xmlns:optimreport="http://www.ibm.com/optim/report/v11.3.0.0"
	xmlns:optimcommon="http://www.ibm.com/optim/common/v11.3.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

	<!-- We only want to import what Archive needs. This approach allows us to easily do reports in reports. 		   -->
	<!-- If we elected to apply the XSL specific to that type, we'd have to worry about conflicts in Common components -->
	<xsl:import href="CommonTemplates.xsl"/>
	<xsl:import href="ReportExtendedObjects.xsl"/>
	<xsl:import href="ReportStatistics.xsl"/>
	<xsl:import href="ReportRelationships.xsl"/>
	<xsl:output method="html" indent="yes" version="4.0"
		doctype-public="-//W3C//DTD HTML 4.01//EN" doctype-system="http://www.w3.org/TR/html4/strict.dtd" />

	<!-- Begin Archive Report Main Section -->
	<xsl:template match="optimreport:ArchiveReport">
		<!--BEGIN SUMMARY SECTION-->
		<xsl:apply-templates select="optimreport:summary[@*]" />
		<!--END SUMMARY SECTION-->
		<xsl:call-template name="anchorSetup">
			<xsl:with-param name="name">procdets</xsl:with-param>
		</xsl:call-template>

		<!-- Process Details Title Bar -->
		<xsl:call-template name="titleBar">
			<xsl:with-param name="name">Process Details</xsl:with-param>
			<xsl:with-param name="containerId">details_container</xsl:with-param>
			<xsl:with-param name="containerClass">details_container_class</xsl:with-param>
			<xsl:with-param name="anchor">procdets</xsl:with-param>
			<xsl:with-param name="closeByDefault">false</xsl:with-param>
			<xsl:with-param name="isInnerReport">false</xsl:with-param>
		</xsl:call-template>

		<!-- Process Details Container -->
		<div id="details_container" class="section_container details_container_class" inAllAction="true">
			<table class="archive_process_details">
				<!-- Call access definition template to determine if we need to display the full section -->
				<!--BEGIN ACCESS DEFINITION-->
				<xsl:apply-templates select="optimreport:localAccessDefinition"/>
				<xsl:apply-templates select="optimreport:accessDefinition" />
				<!--END ACCESS DEFINITION-->
				<xsl:choose>
					<xsl:when test="optimreport:storageProfile">
						<xsl:call-template name="fileTemplate">
							<xsl:with-param name="title">Storage profile</xsl:with-param>
							<xsl:with-param name="name">
								<xsl:call-template name="stringCheck">
									<xsl:with-param name="value" select="optimreport:storageProfile/@name"/>
								</xsl:call-template>
							</xsl:with-param>
							<xsl:with-param name="modifyDate">
								<xsl:call-template name="stringCheck">
									<xsl:with-param name="value" select="optimreport:storageProfile/@modifyDate"/>
								</xsl:call-template>
							</xsl:with-param>
							<xsl:with-param name="secured">
								<xsl:call-template name="stringCheck">
									<xsl:with-param name="value" select="optimreport:storageProfile/@secured"/>
								</xsl:call-template>
							</xsl:with-param>
							<xsl:with-param name="description">
								<xsl:call-template name="stringCheck">
									<xsl:with-param name="value" select="optimreport:storageProfile/@description"/>
								</xsl:call-template>
							</xsl:with-param>
							<xsl:with-param name="id">storage_prof_arrow</xsl:with-param>
							<xsl:with-param name="classname">storage_profile_row</xsl:with-param>
							<xsl:with-param name="isExpand">false</xsl:with-param>
							<xsl:with-param name="style">display:none</xsl:with-param>
							<xsl:with-param name="inallaction">true</xsl:with-param>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="fileTemplate">
							<xsl:with-param name="title">Storage profile</xsl:with-param>
							<xsl:with-param name="name">(None)</xsl:with-param>
							<xsl:with-param name="id">storage_prof_arrow</xsl:with-param>
							<xsl:with-param name="classname">storage_profile_row</xsl:with-param>
							<xsl:with-param name="isExpand">false</xsl:with-param>
							<xsl:with-param name="style">display:none</xsl:with-param>
							<xsl:with-param name="inallaction">true</xsl:with-param>
							<xsl:with-param name="needArrow">false</xsl:with-param>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
				
				<!-- Archive File -->
				<xsl:apply-templates select="optimreport:archiveFile"/>

				<!-- Index File information section -->
				<xsl:apply-templates select="optimreport:indexFile">
					<xsl:with-param name="id">index_file_rows</xsl:with-param>
					<xsl:with-param name="classname">index_file_rows</xsl:with-param>
					<xsl:with-param name="arrowid">index_file_arrow</xsl:with-param>
					<xsl:with-param name="isExpand">false</xsl:with-param>
					<xsl:with-param name="inallaction">true</xsl:with-param>
				</xsl:apply-templates>
				
				<!-- File Attachments section-->
				<xsl:apply-templates select="optimreport:fileAttachments">
					<xsl:with-param name="id">archive_fileattachments_rows</xsl:with-param>
					<xsl:with-param name="classname">archive_fileattachments_rows</xsl:with-param>
					<xsl:with-param name="inAllAction">false</xsl:with-param>
				</xsl:apply-templates>
			</table>

			<!-- Apply the Entities Section -->
			<xsl:if test="optimreport:entities/optimreport:entity">
				<xsl:call-template name="archiveEntities" />
			</xsl:if>
		</div>
		<xsl:apply-templates select="optimreport:extendedObjectTypes" />

		<xsl:if test="optimreport:statistics/optimreport:statistic">
			<xsl:apply-templates select="optimreport:statistics" />
		</xsl:if>
		<xsl:if test="optimreport:relationships/optimreport:relationship">
			<xsl:apply-templates select="optimreport:relationships" />
		</xsl:if>
		<!-- Request Options Section -->
		<xsl:if test="optimreport:requestOptions/*">
			<xsl:apply-templates select="optimreport:requestOptions">
				<xsl:with-param name="display">False</xsl:with-param>
			</xsl:apply-templates>
		</xsl:if>

		<!-- Nested Delete -->
		<xsl:call-template name="anchorSetup">
			<xsl:with-param name="name">heading</xsl:with-param>
		</xsl:call-template>
		<xsl:for-each select="optimreport:DeleteReport">
			<!-- Set up inner report anchor -->
			<xsl:call-template name="anchorSetup">
				<xsl:with-param name="name">innerreport</xsl:with-param>
			</xsl:call-template>

			<xsl:call-template name="sectionSeperator">
				<xsl:with-param name="sectionName">Delete Report</xsl:with-param>
			</xsl:call-template>
			<xsl:apply-templates select=".">
				<xsl:with-param name="display">
					<xsl:text>False</xsl:text>
				</xsl:with-param>
			</xsl:apply-templates>
		</xsl:for-each>
	</xsl:template>
	<!-- END ARCHIVE REPORT MAIN -->

	<!-- Archive Entities Section -->
	<xsl:template name="archiveEntities" >
		<table class="entity_details">
			<tr isTitle="yes">
				<th style="min-width: 125px;">
					<center>
						<b>
							<xsl:text>Name</xsl:text>
						</b>
					</center>
				</th>
				<td >
					<center>
						<b>
							<xsl:text>Status</xsl:text>
						</b>
					</center>
				</td>
				<td >
					<center>
						<b>
							<xsl:text>Archived</xsl:text>
						</b>
					</center>
				</td>
				<td >
					<center>
						<b>
							<xsl:text>Failed</xsl:text>
						</b>
					</center>
				</td>
				<td >
					<center>
						<b>
							<xsl:text>Type</xsl:text>
						</b>
					</center>
				</td>
			</tr>

			<xsl:for-each select="optimreport:entities/optimreport:entity">
					<tr swaparrow="true">
						<th class="drop_down_hover entity_rows" onClick="toggleRows('{generate-id()}_class', event); SwapByClass('blockArrow', '{generate-id()}', event)">
							<xsl:call-template name="arrow">
								<xsl:with-param name="id" select="concat(generate-id(), '_arrow')" />
								<xsl:with-param name="isExpand">false</xsl:with-param>
							</xsl:call-template>
							<xsl:text>&#160;&#160;&#160;</xsl:text>
							<xsl:call-template name="stringCheck">
								<xsl:with-param name="value" select="@name"/>
							</xsl:call-template>
						</th>
						<td>
							<xsl:call-template name="stringCheck">
								<xsl:with-param name="value" select="@status"/>
							</xsl:call-template>
						</td>
						<td class="rightAlignRow">
							<xsl:choose>
								<xsl:when test="string-length(@recordCount) = 0">
									<xsl:text>0</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
										<xsl:when test='not(number(@recordCount) = number(@recordCount))'>
											<xsl:text>(Unavailable)</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@recordCount"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template> 
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="rightAlignRow">
							<xsl:choose>
								<xsl:when test="string-length(@failed) = 0">
									<xsl:text>0</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
										<xsl:when test='not(number(@failed) = number(@failed))'>
											<xsl:text>(Unavailable)</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:call-template name="numberFormat">
												<xsl:with-param name="number" select="@failed"/>
												<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
											</xsl:call-template>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td>
							<xsl:call-template name="stringCheck">
								<xsl:with-param name="value" select="@type"/>
							</xsl:call-template>
						</td>
					</tr>
					<!-- These subsections are for Archive only? -->
					<tr id="{generate-id()}" class="{generate-id()}_class" style="display:none;" inAllAction="true">
						<th class="entity_row">
							<xsl:text>&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;</xsl:text>
							<xsl:text>Active compression status</xsl:text>
						</th>
						<td>
							<xsl:value-of select="optimreport:compression/@status"/>
						</td>
					</tr>
					<xsl:choose>
						<xsl:when test="optimreport:compression/@status='Enabled'">
							<tr id="{generate-id()}" class="{generate-id()}_class" style="display:none;" inAllAction="true">
								<th class="entity_row">
									<xsl:text>&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;</xsl:text>
									<xsl:text>Compression ratio</xsl:text>
								</th>
								<td>
									<xsl:value-of select="optimreport:compression/@value" />
									<xsl:text>%</xsl:text>
								</td>
							</tr>
						</xsl:when>
					</xsl:choose>
			</xsl:for-each>
		</table>
	</xsl:template>

</xsl:stylesheet>

